==> nova_utils-0.0.8.tar.gz: lib/update/ios_update.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nova_utils/update/update_dialog.dart';
import 'package:nova_utils/update/update_utils.dart';
import 'package:package_info/package_info.dart';

import 'ios_update_config.dart';

class IosUpdateDelegate extends UpdateCase {
  IosUpdateConfig config;
  static bool isFirstStart = true;

  @override
  Future checkUpdate(BuildContext context) async {
    config = await getUpdateConfig();
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    String appVersion = packageInfo.version;
    String upNewVersion = config.up_new_version;
    String forceUpdate = config.up_strategy_force;
    var severVersion = int.parse(upNewVersion);
    var currentVersion = int.parse(appVersion);

    //比较本地版本是否小于远程配置版本
    bool needUpdate = severVersion > currentVersion;

    //第一次启动
    if (isFirstStart) {
      isFirstStart = false;
      //如果需要更新
      if (needUpdate) {
        //判断是否需要强制更新
        if (forceUpdate == "true") {
          UpdateDialogUtils.showIosUpDateDialog(context, config);
        } else {
          bool isSkip = await UpdateUtils.isInSkipList(upNewVersion);
          if (!isSkip) {
            UpdateDialogUtils.showIosUpDateDialog(context, config);
          }
        }
      }
    } else {
      if (forceUpdate == "true") {
        UpdateDialogUtils.showIosUpDateDialog(context, config);
      }
    }
  }

  Future<IosUpdateConfig> getUpdateConfig() async {
    if (config == null) {
      IosUpdateConfig data = new IosUpdateConfig();
      config = await data.initConfig();
    }
    return config;
  }
}

==> nova_utils-0.1.1.tar.gz: lib/update/ios_update.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nova_utils/update/update_dialog.dart';
import 'package:nova_utils/update/update_utils.dart';
import 'package:package_info/package_info.dart';

import 'ios_update_config.dart';

class IosUpdateDelegate extends UpdateCase {
  IosUpdateConfig config;
  static bool isFirstStart = true;

  @override
  Future checkUpdate(BuildContext context) async {
    config = await getUpdateConfig();
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    String appVersion = packageInfo.version;
    String upNewVersion = config.up_new_version;
    String forceUpdate = config.up_strategy_force;

    var severVersion = int.parse(upNewVersion.replaceAll(".", ""));
    var currentVersion = int.parse(appVersion.replaceAll(".", ""));

    //比较本地版本是否小于远程配置版本
    bool needUpdate = severVersion > currentVersion;

    //第一次启动
    if (isFirstStart) {
      isFirstStart = false;
      //如果需要更新
      if (needUpdate) {
        //判断是否需要强制更新
        if (forceUpdate == "true") {
          UpdateDialogUtils.showIosUpDateDialog(context, config);
        } else {
          bool isSkip = await UpdateUtils.isInSkipList(upNewVersion);
          if (!isSkip) {
            UpdateDialogUtils.showIosUpDateDialog(context, config);
          }
        }
      }
    } else {
      if (forceUpdate == "true") {
        UpdateDialogUtils.showIosUpDateDialog(context, config);
      }
    }
  }

  Future<IosUpdateConfig> getUpdateConfig() async {
    if (config == null) {
      IosUpdateConfig data = new IosUpdateConfig();
      config = await data.initConfig();
    }
    return config;
  }
}
